@@ -117,7 +117,8 @@ class CloudStackProvider(object):
             return None
 
 
-    def deploy_virtual_machine(self, offering, bundle, project_id, vmname, ):
+    def deploy_virtual_machine(self, offering, bundle,
+        project_id, vmname):
         try:
             request = { 'serviceofferingid': offering,
                   'templateid': bundle.templateid,
